/*
=====================================================================
	TESTBITMAP.CPP (Version 1.02)
    Test of the bitmap module.
	Copyright (c) 2004 Daniel R. Collins. All rights reserved.
	See the bottom of this file for any licensing information.
=====================================================================
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "bitmap.h"


// Main function: makes gray or blue box according to arguments

int main (int argc, char *argv[]) {

  // Need 5 args
  if (argc <= 5) {
    printf("Usage: TESTBITMAP filename width height depth tone\n");
    return 1;
  }

  // Get args
  char *filename = argv[1];
  int width = atoi(argv[2]);
  int height = atoi(argv[3]);
  int depth = atoi(argv[4]);
  int tone = atoi(argv[5]);

  // Width must be a multiple of 4
  if (width % 4 != 0) {
    printf("Error: Width must be a multiple of 4.\n");
    return 1;
  }

  // Depth must be 1 or 3
  if (depth != 1 && depth != 3) {
    printf("Error: Depth must be 1 (grayscale) or 3 (color).\n");
    return 1;
  }

  // Create pixel data array
  int arraySize = width * height * depth;
  unsigned char *data = new unsigned char[arraySize];
  memset(data, 0, arraySize);
  for (int i = 0; i < width * height; i++) {
    data[i * depth] = tone;
  }

  // Save it
  bmpDataSave(data, width, height, depth, filename);

  // Clean up
  delete data;
  return 0;
}

